============
Introduction
============

.. automodule:: qpimage

.. toctree::
  :maxdepth: 2


The background problem
======================


Why qpimage?
============


Citing qpimage
==============
If you are using qpimage in a scientific publication, please
cite it using:

::

  (...) using qpimage version X.X.X (available at
  https://pypi.python.org/pypi/qpimage).

or in a bibliography

::
  
  Paul Müller (2017), qpimage version X.X.X: Phase image analysis
  [Software]. Available at https://pypi.python.org/pypi/qpimage.

and replace ``X.X.X`` with the version of qpimage that you used.


Several ideas implemented in qpimage have been described
and published in scientific journals:

- Phase retrieval from holographic images with a gaussian
  filter is implemented according to :cite:`Schuermann2015`.

- Phase background image correction with a ramp filter fitted to a
  border of the image data was used in :cite:`Schuermann2015` and
  :cite:`Schuermann2016`.

- Intensity background correction by dividing by a reference
  intensity image for tomographic imaging was used in 
  :cite:`Schuermann2017`.
